@@ -1,6 +1,7 @@
 from hasty.attribute import Attribute
 from hasty.client import Client
 from hasty.dataset import Dataset
+from hasty.export_job import ExportJob
 from hasty.image import Image
 from hasty.label import Label
 from hasty.label_class import LabelClass
@@ -15,13 +16,14 @@ def int_or_str(value):
         return value
 
 
-__version__ = '0.0.3'
+__version__ = '0.1.0'
 VERSION = tuple(map(int_or_str, __version__.split('.')))
 
 __all__ = [
     'Attribute',
     'Client',
     'Dataset',
+    'ExportJob',
     'LabelClass',
     'Project',
     'label_utils'
